<script setup>
import 'mapbox-gl/dist/mapbox-gl.css';
import Highcharts from 'highcharts';
import VueMultiselect from 'vue-multiselect';
import DK_Input from '@/components/dk_Input.vue';
import { Link } from '@inertiajs/inertia-vue3';
import DK_Button from '@/components/dk_Button.vue';
import { axiosApiCalls } from '../../../public/libs/datakorumJS';

let AppLayout;

if (window.location.origin.indexOf('localhost:8000') !== -1 || window.location.origin.indexOf('water.baltoro.app') !== -1) {
    AppLayout = require('@/Layouts/AppLayoutWater.vue').default;
} else {
    AppLayout = require('@/Layouts/AppLayoutCity.vue').default;
}

</script>

<style>
</style>

<template>
    <AppLayout title="Vacon">
        <div style="height: calc(100vh - 4.75rem);" class="bg-darkblue-background -z-1 overflow-y-scroll cursor-default">
            <!-- TIME INTERVAL SELECTOR -->
            <div class="mx-6 mt-4 text-xs text-center text-gray-light flex justify-between">
                <div class="grid place-content-center justify-start justify-items-start gap-2">
                    <div class="inline-flex justify-center items-center"> <!--id="routeprofile"-->
                        <p class="text-white-snow font-light text-2xl w-full text-left">{{ this.data.name }}&nbsp;(Id:&nbsp;{{ this.data.id }})</p>
                    </div>
                    <div class="inline-flex justify-center items-center"> <!--id="routeprofile"-->
                        <div class="h-full inline-flex justify-center items-center" v-if="this.data.APN.includes('movistar')">
                            <i class="DK-sim pr-1.5" style="font-size:1rem; margin-right:0rem; color:#d1d1d1; position:relative; top:0%"></i>
                            <p class="text-lg">Movistar</p>
                            <p class="text-lg px-2">-</p>
                        </div>
                        <i class="DK-antena pr-1.5" style="font-size:1rem; margin-right:0rem; color:#d1d1d1; position:relative; top:0%"></i>
                        <p v-if="this.data.D_idstatus == 1" class="text-lg">Online</p>
                        <p v-else class="text-lg">Offline</p>
                        <p class="text-lg px-2">-</p>
                        <p class="text-lg pr-2">{{ this.$t('general.Last sent') + ': ' }}</p>
                        <p class="text-lg">{{ (this.data.dates != undefined && this.data.dates[0]) ? this.data.dates[0] : this.$t('general.Never') }}</p>
                    </div>
                    <div class="mt-2 flex w-full justify-start">
                        <div class="w-fit flex" v-if="this.data.type_name != 'PARK'">
                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.changePage(true)" :off="!this.page_StateParameters" switch="left">
                                {{ this.$t("general.State") }}
                            </DK_Button>

                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.changePage(false)" :off="this.page_StateParameters" switch="right">
                                {{ this.$t("general.Parameters") }}
                            </DK_Button>
                        </div>
                    </div>
                </div>

                <div class="pt-4 grid justify-items-stretch">
                    <div class="flex justify-start items-start">
                        <div class="flex gap-2">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('cityReadings', { idDevice: this.data.id })">
                                <DK_Button color="blue" :fixedSize="true">
                                    {{ this.$t("general.Readings") }}
                                </DK_Button>
                            </Link>

                            <DK_Button color="blue" :fixedSize="true" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                {{ this.$t("general.Back") }}
                            </DK_Button>
                        </div>
                    </div>
                </div>
            </div>

            <div class="w-full p-6" v-bind:class="{'hidden': !this.page_StateParameters}">

                <div class="grid grid-cols-2 place-items-start" v-if="this.data.MODBUS_device_type == 6">
                    <div class="h-fit flex flex-row items-center gap-2 w-[16rem] pb-6">
                        <p class="text-gray-light text-base">{{ this.$t("general.Transducer") }}:</p>
                        <VueMultiselect v-model="this.vmodel_transducer_AI2" placeholder=""
                            :options="this.options_transducer" :close-on-select="true" :multiple="false"
                            label="name" track-by="id" :allow-empty="false"
                            @select="set_options_transducerAI2"/>
                    </div>
                    <div class="h-fit flex flex-row items-center gap-2 w-[16rem] pb-6">
                        <p class="text-gray-light text-base">{{ this.$t("general.Transducer") }}:</p>
                        <VueMultiselect v-model="this.vmodel_transducer_AI1" placeholder=""
                            :options="this.options_transducer" :close-on-select="true" :multiple="false"
                            label="name" track-by="id" :allow-empty="false"
                            @select="set_options_transducerAI1"/>
                    </div>
                </div>
                <div v-else class="h-fit flex flex-row items-center gap-2 w-[16rem] pb-6">
                    <p class="text-gray-light text-base">{{ this.$t("general.Transducer") }}:</p>
                    <VueMultiselect v-model="this.vmodel_transducer" placeholder=""
                        :options="this.options_transducer" :close-on-select="true" :multiple="false"
                        label="name" track-by="id" :allow-empty="false"
                        @select="set_options_transducer"/>
                </div>

                <div class="w-full gap-6 grid grid-cols-6" v-if="this.data.MODBUS_device_type == 6">

                    <div class="flex flex-col justify-between items-center baltoro-container col-span-3">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_0'></a>
                        <div class="w-full h-full p-6 min-h-[14rem]" id='id_chart_0'></div>
                    </div>

                    <div class="flex flex-col justify-between items-center baltoro-container col-span-3">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_1'></a>
                        <div class="w-full h-full p-6 min-h-[14rem]" id='id_chart_1'></div>
                    </div>

                    <!---->

                    <div class="w-full grid grid-cols-5 col-span-6 h-full gap-6 ">
                        <div class="flex flex-col justify-between items-center baltoro-container">
                            <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_2'></a>
                            <div class="w-full h-full pt-2 px-6" id='id_chart_2'></div>
                            <div class="w-full" id='id_label_2'></div>
                        </div>

                        <div class="flex flex-col justify-between items-center baltoro-container">
                            <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_3'></a>
                            <div class="w-full h-full pt-2 px-6" id='id_chart_3'></div>
                            <div class="w-full" id='id_label_3'></div>
                        </div>

                        <!--<div class="flex flex-col justify-between items-center baltoro-container">
                            <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_4'></a>
                            <div class="w-full h-full pt-2 px-6" id='id_chart_4'></div>
                            <div class="w-full" id='id_label_4'></div>
                        </div>-->

                        <div class="flex flex-col justify-between items-center baltoro-container">
                            <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_5'></a>
                            <div class="w-full h-full pt-2 px-6" id='id_chart_5'></div>
                            <div class="w-full" id='id_label_5'></div>
                        </div>

                        <div class="flex flex-col justify-between items-center baltoro-container">
                            <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_6'></a>
                            <div class="w-full h-full pt-2 px-6" id='id_chart_6'></div>
                            <div class="w-full" id='id_label_6'></div>
                        </div>

                        <div class="flex flex-col justify-between items-center baltoro-container">
                            <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_7'></a>
                            <div class="w-full h-full pt-2 px-6" id='id_chart_7'></div>
                            <div class="w-full" id='id_label_7'></div>
                        </div>
                    </div>

                    <!---->

                    <div class="flex flex-col justify-start items-center baltoro-container col-span-2">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_8'></a>
                        <div class="w-full px-6 pb-6 pt-2" id='id_label_8'></div>
                    </div>

                    <div class="flex flex-col h-fit justify-start items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_9'></a>
                        <div class="w-full px-6 flex flex-col justify-center items-center" id='id_label_9'></div>
                    </div>

                    <div class="flex flex-col h-fit justify-start items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_10'></a>
                        <div class="w-full px-6 flex flex-col justify-center items-center" id='id_label_10'></div>
                    </div>

                    <div class="flex flex-col h-fit justify-start items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_11'></a>
                        <div class="w-full px-6 flex flex-col justify-center items-center" id='id_label_11'></div>
                    </div>

                    <div class="flex flex-col h-fit justify-start items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_12'></a>
                        <div class="w-full px-6 flex flex-col justify-center items-center" id='id_label_12'></div>
                    </div>
                </div>

                <div class="w-full gap-6 grid grid-cols-6" v-else>

                    <div class="flex flex-col justify-between items-center baltoro-container col-span-3">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_0'></a>
                        <div class="w-full h-full p-6 min-h-[14rem]" id='id_chart_0'></div>
                    </div>

                    <div class="flex flex-col justify-between items-center baltoro-container col-span-3">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_1'></a>
                        <div class="w-full h-full p-6 min-h-[14rem]" id='id_chart_1'></div>
                    </div>

                    <!---->

                    <div class="flex flex-col justify-between items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_2'></a>
                        <div class="w-full h-full pt-2 px-6" id='id_chart_2'></div>
                        <div class="w-full" id='id_label_2'></div>
                    </div>

                    <div class="flex flex-col justify-between items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_3'></a>
                        <div class="w-full h-full pt-2 px-6" id='id_chart_3'></div>
                        <div class="w-full" id='id_label_3'></div>
                    </div>

                    <div class="flex flex-col justify-between items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_4'></a>
                        <div class="w-full h-full pt-2 px-6" id='id_chart_4'></div>
                        <div class="w-full" id='id_label_4'></div>
                    </div>

                    <div class="flex flex-col justify-between items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_5'></a>
                        <div class="w-full h-full pt-2 px-6" id='id_chart_5'></div>
                        <div class="w-full" id='id_label_5'></div>
                    </div>

                    <div class="flex flex-col justify-between items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_6'></a>
                        <div class="w-full h-full pt-2 px-6" id='id_chart_6'></div>
                        <div class="w-full" id='id_label_6'></div>
                    </div>

                    <div class="flex flex-col justify-between items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_7'></a>
                        <div class="w-full h-full pt-2 px-6" id='id_chart_7'></div>
                        <div class="w-full" id='id_label_7'></div>
                    </div>

                    <!---->

                    <div class="flex flex-col justify-start items-center baltoro-container col-span-2">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_8'></a>
                        <div class="w-full px-6 pb-6 pt-2" id='id_label_8'></div>
                    </div>

                    <div class="flex flex-col h-fit justify-start items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_9'></a>
                        <div class="w-full px-6 flex flex-col justify-center items-center" id='id_label_9'></div>
                    </div>

                    <div class="flex flex-col h-fit justify-start items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_10'></a>
                        <div class="w-full px-6 flex flex-col justify-center items-center" id='id_label_10'></div>
                    </div>

                    <div class="flex flex-col h-fit justify-start items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_11'></a>
                        <div class="w-full px-6 flex flex-col justify-center items-center" id='id_label_11'></div>
                    </div>

                    <div class="flex flex-col h-fit justify-start items-center baltoro-container">
                        <a class="text-base text-center text-cyan-text font-normal mt-2 mb-1 whitespace-nowrap" id='id_title_12'></a>
                        <div class="w-full px-6 flex flex-col justify-center items-center" id='id_label_12'></div>
                    </div>
                </div>
            </div>

            <div class="p-6 gap-6 flex" v-bind:class="{'hidden': this.page_StateParameters || this.data.MODBUS_device_type != 6}">
                <div class="flex flex-col justify-between items-start baltoro-container px-6 pb-3 pt-4 w-fit h-fit gap-4">
                    <div class="flex flex-col items-start justify-start gap-4 w-full">
                        <a class="font-normal text-left text-white-snow text-2xl whitespace-nowrap">{{this.$t('general.Actuators')}}</a>
                        <div class="w-full flex gap-y-6 gap-x-12 justify-center">
                            <div class="flex flex-col items-start gap-2 justify-between 2xl:w-[17.5rem] w-[15rem]">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Relay status')}}</a>
                                <VueMultiselect v-model="this.vmodel_idstatus" placeholder=""
                                        :options="this.options_idstatus" :close-on-select="true" :multiple="false"
                                        label="name" track-by="id" :allow-empty="false"/>
                            </div>
                        </div>
                    </div>
                    <div class="mt-2 flex justify-center gap-3 w-full">
                        <DK_Button color="blue" :fixedSize="true" id="id_update_button1" v-on:click='this.Command(0)' :off="this.timeout_command != undefined" :disabled="this.timeout_command != undefined">
                            {{ this.$t("general.Update") }}
                        </DK_Button>
                        <DK_Button color="blue" :fixedSize="true" v-on:click='this.CancelCommand(0)'>
                            {{ this.$t("general.Cancel") }}
                        </DK_Button>
                    </div>
                </div>

                <div class="flex flex-col justify-between items-start baltoro-container px-6 pb-3 pt-4 w-full h-fit gap-4">
                    <div class="flex flex-col items-start justify-start gap-4 w-full">
                        <a class="font-normal text-left text-white-snow text-2xl whitespace-nowrap">{{this.$t('general.Registers')}}</a>
                        <div class="w-full grid 2xl:grid-cols-4 grid-cols-3 gap-y-6 gap-x-auto place-items-center">
                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Rated motor current (A)')}}</a>
                                <DK_Input id="id_rated_motor" type="text" :value="this.ini_rated_motor" :border="true" textPosition="center" width="full"/>
                            </div>
                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Start function')}}</a>
                                <VueMultiselect v-model="this.vmodel_startfunction" placeholder=""
                                        :options="this.options_startfunction" :close-on-select="true" :multiple="false"
                                        label="name" track-by="id" :allow-empty="false"/>
                            </div>
                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Stop function')}}</a>
                                <VueMultiselect v-model="this.vmodel_stopfunction" placeholder=""
                                        :options="this.options_stopfunction" :close-on-select="true" :multiple="false"
                                        label="name" track-by="id" :allow-empty="false"/>
                            </div>

                            <!---->

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Minimum frequency (Hz)')}}</a>
                                <DK_Input id="id_min_f" type="text" :value="this.ini_min_f" :border="true" textPosition="center" width="full"/>

                            </div>
                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Set point (%)')}}</a>
                                <DK_Input id="id_set_point" type="text" :value="this.ini_set_point" :border="true" textPosition="center" width="full"/>

                            </div>
                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Proportional gain (%)')}}</a>
                                <DK_Input id="id_prop_gain" type="text" :value="this.ini_prop_gain" :border="true" textPosition="center" width="full"/>
                            </div>

                            <!---->

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Integration time (s)')}}</a>
                                <DK_Input id="id_integration_time" type="text" :value="this.ini_integration_time" :border="true" textPosition="center" width="full"/>

                            </div>
                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Derivation time (s)')}}</a>
                                <DK_Input id="id_derivation_time" type="text" :value="this.ini_derivation_time" :border="true" textPosition="center" width="full"/>

                            </div>
                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Minimum sleep frequency (Hz)')}}</a>
                                <DK_Input id="id_min_sleep_f" type="text" :value="this.ini_min_sleep_f" :border="true" textPosition="center" width="full"/>

                            </div>

                            <!---->

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Sleep delay (s)')}}</a>
                                <DK_Input id="id_sleep_delay" type="text" :value="this.ini_sleep_delay" :border="true" textPosition="center" width="full"/>

                            </div>
                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Wake-up error (%)')}}</a>
                                <DK_Input id="id_wake_up_error" type="text" :value="this.ini_wake_up_error" :border="true" textPosition="center" width="full"/>

                            </div>
                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Parameter hiding')}}</a>
                                <VueMultiselect v-model="this.vmodel_parameterhiding" placeholder=""
                                        :options="this.options_parameterhiding" :close-on-select="true" :multiple="false"
                                        label="name" track-by="id" :allow-empty="false"/>
                            </div>
                        </div>
                    </div>
                    <div class="mt-2 flex justify-center gap-3 w-full">
                        <DK_Button color="blue" :fixedSize="true" id="id_update_button2" v-on:click='this.Command(1)' :off="this.timeout_command != undefined" :disabled="this.timeout_command != undefined">
                            {{ this.$t("general.Update") }}
                        </DK_Button>
                        <DK_Button color="blue" :fixedSize="true" v-on:click='this.CancelCommand(1)'>
                            {{ this.$t("general.Cancel") }}
                        </DK_Button>
                    </div>
                </div>
            </div>

            <div class="p-6 gap-6 flex" v-bind:class="{'hidden': this.page_StateParameters || this.data.MODBUS_device_type != 7}">
                <div class="flex flex-col justify-between items-start baltoro-container px-6 pb-3 pt-4 w-fit h-fit gap-4">
                    <div class="flex flex-col items-start justify-start gap-4 w-full">
                        <a class="font-normal text-left text-white-snow text-2xl whitespace-nowrap">{{this.$t('general.Actuators')}}</a>
                        <div class="w-full flex gap-y-6 gap-x-12 justify-center">
                            <div class="flex flex-col items-start gap-2 justify-between 2xl:w-[17.5rem] w-[15rem]">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Relay status')}}</a>
                                <VueMultiselect v-model="this.vmodel_idstatus" placeholder=""
                                        :options="this.options_idstatus" :close-on-select="true" :multiple="false"
                                        label="name" track-by="id" :allow-empty="false"/>
                            </div>
                        </div>
                    </div>
                    <div class="mt-2 flex justify-center gap-3 w-full">
                        <DK_Button color="blue" :fixedSize="true" id="id_update_button1" v-on:click='this.Command(0)' :off="this.timeout_command != undefined" :disabled="this.timeout_command != undefined">
                            {{ this.$t("general.Update") }}
                        </DK_Button>
                        <DK_Button color="blue" :fixedSize="true" v-on:click='this.CancelCommand(0)'>
                            {{ this.$t("general.Cancel") }}
                        </DK_Button>
                    </div>
                </div>

                <div class="flex flex-col justify-between items-start baltoro-container px-6 pb-3 pt-4 w-full h-fit gap-4">
                    <div class="flex flex-col items-start justify-start gap-4 w-full">
                        <a class="font-normal text-left text-white-snow text-2xl whitespace-nowrap">{{this.$t('general.Registers')}}</a>
                        <div class="w-full grid 2xl:grid-cols-4 grid-cols-3 gap-y-6 gap-x-auto place-items-center">

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap"> rearme </a>
                                <VueMultiselect v-model="this.vmodel_rearme" placeholder=""
                                        :options="this.options_rearme" :close-on-select="true" :multiple="false"
                                        label="name" track-by="id" :allow-empty="false"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">consigna</a>
                                <DK_Input id="id_consigna" type="text" :value="this.ini_consigna" :border="true" textPosition="center" width="full"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">int_nom</a>
                                <DK_Input id="id_int_nom" type="text" :value="this.ini_int_nom" :border="true" textPosition="center" width="full"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">frec_min</a>
                                <DK_Input id="id_frec_min" type="text" :value="this.ini_frec_min" :border="true" textPosition="center" width="full"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">ganancia_pid</a>
                                <DK_Input id="id_ganancia_pid" type="text" :value="this.ini_ganancia_pid" :border="true" textPosition="center" width="full"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">tiempo_int_pid</a>
                                <DK_Input id="id_tiempo_int_pid" type="text" :value="this.ini_tiempo_int_pid" :border="true" textPosition="center" width="full"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">lim_frec_dormir_1</a>
                                <DK_Input id="id_lim_frec_dormir_1" type="text" :value="this.ini_lim_frec_dormir_1" :border="true" textPosition="center" width="full"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">retraso_dormir_sp1</a>
                                <DK_Input id="id_retraso_dormir_sp1" type="text" :value="this.ini_retraso_dormir_sp1" :border="true" textPosition="center" width="full"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">modo_despertar_ref_1_pid</a>
                                <VueMultiselect v-model="this.vmodel_modo_despertar_ref_1_pid" placeholder=""
                                        :options="this.options_modo_despertar_ref_1_pid" :close-on-select="true" :multiple="false"
                                        label="name" track-by="id" :allow-empty="false"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">nivel_despertar_1</a>
                                <DK_Input id="id_nivel_despertar_1" type="text" :value="this.ini_nivel_despertar_1" :border="true" textPosition="center" width="full"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">hora</a>
                                <DK_Input id="id_hora" type="text" :value="this.ini_hora" :border="true" textPosition="center" width="full"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">fecha</a>
                                <DK_Input id="id_fecha" type="text" :value="this.ini_fecha" :border="true" textPosition="center" width="full"/>
                            </div>

                            <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">anyo</a>
                                <DK_Input id="id_anyo" type="text" :value="this.ini_anyo" :border="true" textPosition="center" width="full"/>
                            </div>
                        </div>
                    </div>
                    <div class="mt-2 flex justify-center gap-3 w-full">
                        <DK_Button color="blue" :fixedSize="true" id="id_update_button2" v-on:click='this.Command(2)' :off="this.timeout_command != undefined" :disabled="this.timeout_command != undefined">
                            {{ this.$t("general.Update") }}
                        </DK_Button>
                        <DK_Button color="blue" :fixedSize="true" v-on:click='this.CancelCommand(2)'>
                            {{ this.$t("general.Cancel") }}
                        </DK_Button>
                    </div>
                </div>
            </div>

        </div>
    </AppLayout>
</template>

<script>
export default {
    props: [ 'data', 'user'],

    data() {
        return {
            Back: localStorage.getItem('Back'),
            Chart: {},
            page_StateParameters: this.data.page_init == 1 ? true : false,
            Highcharts: require('highcharts'),
            timeout_command: undefined,

            //INITIAL STATES

            ini_digital_inputs: (this.data.digital_inputs) ? Object.values(this.data.digital_inputs) : null,

            ini_transducer: (this.data.transducer != false) ? (parseFloat(this.data.transducer)) : 0,
            ini_transducerAI1: (this.data.transducerAI1 != false) ? (parseFloat(this.data.transducerAI1)) : 0,
            ini_transducerAI2: (this.data.transducerAI2 != false) ? (parseFloat(this.data.transducerAI2)) : 0,
            ini_idstatus: (this.data.O_idstatus) ? (parseFloat(this.data.O_idstatus)) : null,

            ini_startfunction: (this.data.registers[0] != undefined && this.data.registers[0].arranque) ? (parseFloat(this.data.registers[0].arranque)) : null,
            ini_stopfunction: (this.data.registers[0] != undefined && this.data.registers[0].parada) ? (parseFloat(this.data.registers[0].parada)) : null,
            ini_parameterhiding: (this.data.registers[0] != undefined && this.data.registers[0].ocult_param) ? (parseFloat(this.data.registers[0].ocult_param)) : null,

            ini_rated_motor: (this.data.registers[0] != undefined && this.data.registers[0].corr_nom) ? (parseFloat(this.data.registers[0].corr_nom) * 0.01) : null,
            ini_min_f: (this.data.registers[0] != undefined && this.data.registers[0].frec_min) ? (parseFloat(this.data.registers[0].frec_min) * 0.01) : null,
            ini_set_point: (this.data.registers[0] != undefined && this.data.registers[0].consigna) ? (parseFloat(this.data.registers[0].consigna) * 0.1) : null,
            // ini_prop_gain: parseInt(this.data.registers[0] != undefined && this.data.registers[0].ganancia_p),
            ini_prop_gain: (this.data.registers[0] != undefined && this.data.registers[0].ganancia_p) ? (parseFloat(this.data.registers[0].ganancia_p) * 0.1) : null,
            ini_integration_time: (this.data.registers[0] != undefined && this.data.registers[0].tiempo_i) ? (parseFloat(this.data.registers[0].tiempo_i) * 0.01) : null,
            ini_derivation_time: (this.data.registers[0] != undefined && this.data.registers[0].tiempo_d) ? (parseFloat(this.data.registers[0].tiempo_d) * 0.01) : null,
            ini_min_sleep_f: (this.data.registers[0] != undefined && this.data.registers[0].frec_min_dormir) ? (parseFloat(this.data.registers[0].frec_min_dormir) * 0.01) : null,
            ini_sleep_delay: (this.data.registers[0] != undefined && this.data.registers[0].retardo_dormir) ? (parseFloat(this.data.registers[0].retardo_dormir)) : null,
            ini_wake_up_error: (this.data.registers[0] != undefined && this.data.registers[0].error_despertar) ? (parseFloat(this.data.registers[0].error_despertar) * 0.1) : null,

            ini_rearme: (this.data.registers[0] != undefined && this.data.registers[0].rearme) ? (parseFloat(this.data.registers[0].rearme)) : null, //
            ini_consigna: (this.data.registers[0] != undefined && this.data.registers[0].consigna) ? (parseFloat(this.data.registers[0].consigna)) : null,
            ini_int_nom: (this.data.registers[0] != undefined && this.data.registers[0].int_nom) ? (parseFloat(this.data.registers[0].int_nom)) : null,
            ini_frec_min: (this.data.registers[0] != undefined && this.data.registers[0].frec_min) ? (parseFloat(this.data.registers[0].frec_min)) : null,
            ini_ganancia_pid: (this.data.registers[0] != undefined && this.data.registers[0].ganancia_pid) ? (parseFloat(this.data.registers[0].ganancia_pid)) : null,
            ini_tiempo_int_pid: (this.data.registers[0] != undefined && this.data.registers[0].tiempo_int_pid) ? (parseFloat(this.data.registers[0].tiempo_int_pid)) : null,
            ini_lim_frec_dormir_1: (this.data.registers[0] != undefined && this.data.registers[0].lim_frec_dormir_1) ? (parseFloat(this.data.registers[0].lim_frec_dormir_1)) : null,
            ini_retraso_dormir_sp1: (this.data.registers[0] != undefined && this.data.registers[0].retraso_dormir_sp1) ? (parseFloat(this.data.registers[0].retraso_dormir_sp1)) : null,
            ini_modo_despertar_ref_1_pid: (this.data.registers[0] != undefined && this.data.registers[0].modo_despertar_ref_1_pid) ? (parseFloat(this.data.registers[0].modo_despertar_ref_1_pid)) : null, //
            ini_nivel_despertar_1: (this.data.registers[0] != undefined && this.data.registers[0].nivel_despertar_1) ? (parseFloat(this.data.registers[0].nivel_despertar_1)) : null,
            ini_hora: (this.data.registers[0] != undefined && this.data.registers[0].hora) ? (parseFloat(this.data.registers[0].hora)) : null,
            ini_fecha: (this.data.registers[0] != undefined && this.data.registers[0].fecha) ? (parseFloat(this.data.registers[0].fecha)) : null,
            ini_anyo: (this.data.registers[0] != undefined && this.data.registers[0].anyo) ? (parseFloat(this.data.registers[0].anyo)) : null,

            //OPTIONS
            options_transducer: undefined,
            options_idstatus: undefined,
            options_startfunction: undefined,
            options_stopfunction: undefined,
            options_parameterhiding: undefined,
            options_rearme: undefined,
            options_modo_despertar_ref_1_pid: undefined,

            //VMODELS
            vmodel_transducer: undefined,
            vmodel_transducer_AI1: undefined,
            vmodel_transducer_AI2: undefined,
            vmodel_idstatus: undefined,
            vmodel_startfunction: undefined,
            vmodel_stopfunction: undefined,
            vmodel_parameterhiding: undefined,
            vmodel_rearme: undefined,
            vmodel_modo_despertar_ref_1_pid: undefined,

            //FORMATS
            formatDate: (date, utc) => {
                date = new Date(date);
                // utc en 0 para formatear hora local del usuario, 1 para formatear UTC
                if (utc == 0) { date.setHours(date.getHours() + this.user.timezone_offset) }
                else if (utc == -1) { date.setHours(date.getHours() - this.user.timezone_offset) }
                return (
                    date.getFullYear() + "-" +
                    ((date.getMonth() + 1 + '').length < 2 ? "0" + (date.getMonth() + 1) : (date.getMonth() + 1)) + "-" +
                    ((date.getDate() + '').length < 2 ? "0" + date.getDate() : date.getDate()) + " " +
                    ((date.getHours() + '').length < 2 ? "0" + date.getHours() : date.getHours()) + ":" +
                    ((date.getMinutes() + '').length < 2 ? "0" + date.getMinutes() : date.getMinutes()) + ":" +
                    ((date.getSeconds() + '').length < 2 ? "0" + date.getSeconds() : date.getSeconds())
                );
            },
        }
    },

    beforeCreate() {
        this.$i18n.locale = this.user.language
    },

    beforeMount() {

        this.options_transducer = [
            {
                id: 0,
                name: '0 → 10 (bar)',
                ratio: 0.10,
            },{
                id: 1,
                name: '0 → 15 (bar)',
                ratio: 0.15,
            },{
                id: 2,
                name: '0 → 16 (bar)',
                ratio: 0.16,
            },{
                id: 3,
                name: '0 → 20 (bar)',
                ratio: 0.20,
            },{
                id: 4,
                name: '0 → 25 (bar)',
                ratio: 0.25,
            },
        ];

        this.options_idstatus = [
            {
                id: 0,
                name: this.$t('general.OFF'),
            },{
                id: 1,
                name: this.$t('general.ON'),
            },
        ];

        this.options_startfunction = [
            {
                id: 0,
                name: this.$t('general.Ramp'),
            },{
                id: 1,
                name: this.$t('general.Start on the fly'),
            },
        ];

        this.options_stopfunction = [
            {
                id: 0,
                name: this.$t('general.Free'),
            },{
                id: 1,
                name: this.$t('general.Ramp'),
            },
        ];

        this.options_parameterhiding = [
            {
                id: 0,
                name: this.$t('general.All visible'),
            },{
                id: 1,
                name: this.$t('general.Configuration group only'),
            },
        ];

        this.options_rearme = [
            {
                id: 0,
                name: '0',
            },{
                id: 1,
                name: '1',
            },
        ];

        this.options_modo_despertar_ref_1_pid = [
            {
                id: 0,
                name: 'Absolute level',
            },{
                id: 1,
                name: 'Relative setpoint',
            },
        ];

        this.vmodel_transducer = this.options_transducer[this.ini_transducer];
        this.vmodel_transducer_AI1 = this.options_transducer[this.ini_transducerAI1];
        this.vmodel_transducer_AI2 = this.options_transducer[this.ini_transducerAI2];

        this.vmodel_idstatus = this.options_idstatus[this.ini_idstatus];
        this.vmodel_startfunction = this.options_startfunction[this.ini_startfunction];
        this.vmodel_stopfunction = this.options_stopfunction[this.ini_stopfunction];
        this.vmodel_parameterhiding = this.options_parameterhiding[this.ini_parameterhiding];
        this.vmodel_rearme = this.options_rearme[this.ini_rearme];
        this.vmodel_modo_despertar_ref_1_pid = this.options_modo_despertar_ref_1_pid[this.ini_modo_despertar_ref_1_pid];
    },

    mounted() {

        this.mqtt_connection(this.data.id);

        window.emitter.emit('changeLoaderStatus', false, 'orbit')

        let formatDate = this.formatDate;

        this.Chart = {
            chart: {
                zoomType: 'x',
                backgroundColor: 'transparent',
                animation: {
                    duration: 150
                },
                resetZoomButton: {
                    position: {
                        align: 'left',
                        verticalAlign: 'top',
                        x: 0,
                        y: 2.5
                    },
                    theme: {
                        r: 5.6,
                    }
                }
            },
            accessibility: {
                enabled: false
            },
            title: {
                text: ''
            },
            xAxis: {
                visible: true,
                labels: {
                    style: {
                        color: 'rgba(200, 200, 200, 0.9)',
                        opacity: 0.7,
                    }
                },
                type: "datetime",
                dateTimeLabelFormats: {
                    week: '%m-%d',
                    month: '%Y-%m',
                    year: '%Y'
                },
                time: {
                    timezoneOffset: new Date().getTimezoneOffset(), // Configura la zona horaria actual
                    useUTC: true // Utiliza hora local
                }
            },
            yAxis: [{
                title: {
                text: ''
                },
                labels: {
                    formatter: function () {
                        return this.pos + '  ' + this.chart.userOptions.series[0].tooltip.valueSuffix
                    },
                    style: {
                        color: 'rgba(200, 200, 200, 0.9)',
                        opacity: 0.7,
                    }
                },
                //tickPositions: [0, 50, 100],
                visible: true,
            }],
            plotOptions: {
                column: {
                    borderWidth: 0
                }
            },
            exporting: {
                enabled: false
            },
            credits: {
                enabled: false
            },
            legend: {
                enabled: false,
            },

            tooltip: {
                shared: true,
                split: false,
                backgroundColor: 'rgba(7,82,103,0.95)',
                borderRadius: 12,
                borderWidth: 1,
                borderColor: 'rgba(250, 250, 250, 0.65)',
                padding: 6,
                formatter: function () {
                    var s = '<b>' + '<p style="font-size:12px; line-height: 12px; font-weight: 300; color:rgba(250, 250, 250, 0.95)">' + formatDate(this.x, -1) + '</p><br/>';
                    $.each(this.points, function () {
                        s += '<p style="font-size:12px; line-height: 12px; font-weight: 400; color:' + this.series.color + '">' + this.series.name + ' </p><p style="font-size:12px; line-height: 12px; font-weight: 400; color:' + this.series.color + '">' + this.y +
                            ' ' + this.series.userOptions.tooltip.valueSuffix + '</p><br/>';
                    });

                    return s;
                },
            },
        };

        this.rechargePage();

    },

    methods: {

        rechargePage() {

            const Highcharts = require('highcharts');
            require('highcharts/highcharts-more')(Highcharts);

            if(this.data.MODBUS_device_type == 6 && this.page_StateParameters && this.data.data){

                let sensor_num = Object.keys(this.data.data).length;
                let index_i;

                let units = new Array(sensor_num);
                let names = new Array(sensor_num);
                let data = new Array(sensor_num);
                let dates;

                for (let sensor in this.data.data) {

                    if(sensor == 9 || sensor == 15){ // GRAFICOS

                        switch(sensor){
                            case '9': index_i = 0; break;
                            case '15': index_i = 1; break;
                        }

                        document.getElementById("id_title_" + index_i).innerHTML = (this.data.units[sensor] != '') ? (this.data.names[sensor] + " (" + this.data.units[sensor] + ")") : (this.data.names[sensor]);

                        dates = new Array(this.data.data[sensor].length);
                        data[index_i] = new Array(this.data.data[sensor].length);
                        names[index_i] = this.data.names[sensor];
                        units[index_i] = this.data.units[sensor];

                        this.data.data[sensor].forEach((value, index) => {

                            dates[index] = new Date(
                                (this.data.dates[index] + " GMT")
                            ).getTime();

                            if (index_i == 0) {
                                data[index_i][index] = parseFloat((parseFloat(value) * this.options_transducer[this.vmodel_transducer_AI2.id].ratio).toFixed(2));
                            } else {
                                data[index_i][index] = parseFloat((parseFloat(value) * this.options_transducer[this.vmodel_transducer_AI1.id].ratio).toFixed(2));
                            }

                        });

                        /*switch(sensor){
                            case '15': index_i = 5; break;
                            case '9': index_i = 9; break;
                        }

                        document.getElementById("id_title_" + index_i).innerHTML = this.data.names[sensor];

                        data[index_i] = this.data.data[sensor][0];
                        names[index_i] = this.data.names[sensor];
                        units[index_i] = this.data.units[sensor];*/

                    }else if(!(sensor == 10 || sensor == 11 || sensor == 12) && sensor != 17){ // GAUGES && TEXTS

                        switch(sensor){
                            case '14': index_i = 2; break;
                            case '16': index_i = 3; break;
                            //case '17': index_i = 4; break;
                            case '1': index_i = 5; break;
                            case '6': index_i = 6; break;
                            case '3': index_i = 7; break;
                            case '7': index_i = 11; break;
                            case '8': index_i = 12; break;
                        }

                        document.getElementById("id_title_" + index_i).innerHTML = this.data.names[sensor];

                        data[index_i] = this.data.data[sensor][0];
                        names[index_i] = this.data.names[sensor];
                        units[index_i] = this.data.units[sensor];

                    } else if(sensor == 10 || sensor == 11 || sensor == 12){ // WORDS

                        switch(sensor){
                            case '10': index_i = 10; break;
                            case '11': index_i = 9; break;
                            case '12': index_i = 8; break;
                        }

                        document.getElementById("id_title_" + index_i).innerHTML = this.data.names[sensor];

                        data[index_i] = this.data.data[sensor][0];
                        names[index_i] = this.data.names[sensor];
                        units[index_i] = this.data.units[sensor] == null ? '' : this.data.units[sensor];

                    }

                }

                data.forEach((sensor, index) => {

                    let Chart = this.Chart;

                    if(typeof sensor === 'object'){ // GRAFICO

                        let highcharts_data = new Array(sensor.length);

                        sensor.forEach((measure, index) => {
                            highcharts_data[index] = [dates[index], parseFloat(measure)];
                        });

                        Chart.tooltip.valueSuffix = units[index];

                        Chart.series = [
                        {
                            name: names[index],
                            type: "spline",
                            data: highcharts_data.reverse(),
                            color: "#05fff3",
                            lineWidth: 1.5,
                            zIndex: 1,
                            marker: {
                            enabled: false,
                            },
                            tooltip: {
                                valueSuffix: units[index],
                            },
                        },
                        ];

                        Highcharts.chart("id_chart_" + index, Chart);

                    }else if(index == 2 || index == 3 || index == 5 || index == 6 || index == 7){ // GAUGE

                        let max;

                        switch(index){
                            case 5: max = 60; break;
                            case 6: max = 600; break;
                            case 7: max = 25; break;
                            default:  max = 100; break;
                        }

                        let min;

                        switch(index){
                            default:  min = 0; break;
                        }

                        Chart = {
                            chart: {
                                type: 'gauge',
                                backgroundColor: "transparent",
                                plotBackgroundColor: null,
                                plotBackgroundImage: null,
                                plotBorderWidth: 0,
                                plotShadow: false,
                                spacing: [0, 0, 0, 0], // Ajusta los márgenes del gráfico según tus necesidades
                                height: 120,
                                marginTop: -5, // Elimina el margen superior del gráfico
                                marginBottom: -35,
                            },
                            title: null,
                            pane: {
                                startAngle: -120,
                                endAngle: 120,
                                background: {
                                backgroundColor: "transparent",
                                borderWidth: 0
                                }
                            },
                            tooltip: {
                                enabled: false
                            },
                            xAxis: {
                                title: {
                                text: "",
                                style: {
                                    color: "#FFFAFA",
                                    fontSize: "12px",
                                    fontWeight: "normal",
                                    fontStyle: "normal"
                                }
                                },
                                labels: {
                                    rotation: -45,
                                    style: {
                                        color: 'white',
                                        fontSize: '10px' // Ajusta el tamaño de la fuente de las etiquetas según tus necesidades
                                    }
                                }
                            },
                            yAxis: {
                                min: min,
                                max: max,
                                tickPosition: 'outside',
                                lineColor: '#05fff3',
                                lineWidth: 1, // Ajusta el ancho de la línea del eje según tus necesidades
                                minorTickPosition: 'outside',
                                tickColor: '#05fff3',
                                minorTickColor: '#05fff3',
                                tickLength: 4, // Ajusta la longitud de las marcas del eje según tus necesidades
                                minorTickWidth: 1,
                                tickWidth: 1,
                                minorTickLength: 3, // Ajusta la longitud de las marcas menores del eje según tus necesidades
                                labels: {
                                distance: 6, // Ajusta la distancia de las etiquetas al eje según tus necesidades
                                rotation: 'auto',
                                style: {
                                    color: '#05fff3',
                                    fontSize: '10px' // Ajusta el tamaño de la fuente de las etiquetas según tus necesidades
                                }
                                },
                                tickPositions:
                                [
                                    min,
                                    min + (max-min)/4,
                                    min + (max-min)/2,
                                    min + 3*(max-min)/4,
                                    max
                                ],
                                offset: -10,
                                endOnTick: false
                            },
                            plotOptions: {
                                gauge: {
                                    borderWidth: 0,
                                    borderColor: "#05fff3", // Cambia el color del borde de la serie a #05fff3
                                    dataLabels: {
                                        enabled: false, // Desactiva las etiquetas con el dato y su unidad
                                    },
                                    pivot: {
                                        radius: "4%",
                                        backgroundColor: "#fff", // Cambia el color del pivote a blanco
                                    },
                                    dial: {
                                        backgroundColor: "#fff", // Cambia el color de la flecha a blanco
                                        radius: "70%", // Ajusta el tamaño de la flecha según tus necesidades
                                        baseWidth: 3, // Ajusta el ancho de la base de la flecha según tus necesidades
                                        topWidth: 1, // Ajusta el ancho de la punta de la flecha según tus necesidades
                                        baseLength: "10%", // Ajusta la longitud de la base de la flecha según tus necesidades
                                        rearLength: "-20%", // Ajusta la longitud de la punta de la flecha según tus necesidades
                                    }
                                },
                            },
                            credits: {
                                enabled: false
                            },
                            exporting: {
                                enabled: false,
                            },
                            series: [{
                                name: '',
                                data: [{
                                y:  parseFloat(sensor),
                                }],
                                tooltip: {
                                valueSuffix: ''
                                }
                            }]
                        };

                        Highcharts.chart("id_chart_" + index, Chart);

                        var content =
                        '<div class="content-between m-0 cursor-default text-base w-full pb-2">' +
                            '<div class="text-center flex justify-center items-center w-full whitespace-nowrap gap-2 pl-4">' +
                                '<p class="text-3xl font-sevensegment text-white-snow">' + sensor + '</p>' +
                                '<p class="text-white-snow pb-0.5 self-end text-left">' + units[index] + '</p>' +
                            '</div>' +
                        '</div>'

                        document.getElementById("id_label_" + index).innerHTML = content;

                    }else if(index == 11 || index == 12){ // TEXTS

                        var content = '';
                        var icon_class =
                            (index === 11) ? 'DK-voltaje' :
                            (index === 12) ? 'DK-temperatura' :
                            'hidden';

                        switch(index){
                            case 11: case 12:
                                content +=
                                '<div class="content-between m-0 cursor-default text-base w-full">' +
                                    '<div class="bg-cyan-opa px-2 mb-3 py-2 mt-1 text-center rounded-lg flex justify-center items-center w-full whitespace-nowrap gap-4">' +
                                        '<div class="h-6 w-6 rounded-full bg-transparent border border-white grid place-items-center justify-self-start">' +
                                            '<i class="' + icon_class + '" style="font-size:0.9rem; color:#FFFAFA;"></i>' +
                                        '</div>' +
                                        '<p class="text-3xl font-sevensegment text-white-snow">' + sensor + '</p>' +
                                        '<p class="text-white-snow self-end w-4 text-left pb-0.5">' + units[index] + '</p>' +
                                    '</div>' +
                                '</div>'
                                break;
                        }

                        document.getElementById("id_label_" + index).innerHTML = content;

                    } else { // WORDS

                        /*if( index == 11 ){

                            //B3 = Rampa 2 activa; B5 = Lugar de CTRL remoto 1 activado; B6 = Lugar de CTRL remoto 2 activado; B7 = Control activo de bus de campo; B8 = Control activo local; B9 = Control activo de PC; B10 = Frecuencias constantes activas

                            let decode_word = [];

                            for (let i = sensor.toString().length - 1; i >= 0; i--) {
                                decode_word.push((sensor.toString()[i] == 1 || sensor.toString()[i] == '1') ? true : false)
                            }

                            while(decode_word.length <= 10){
                                decode_word.push(false)
                            }

                            content = '<div class="grid grid-cols-6 m-0 cursor-default w-full gap-2 pt-1 2xl:text-xl text-lg">';

                            decode_word.forEach( (bool, index) => {

                                switch (index) {
                                    case 3:
                                    content += '<div class="col-span-3 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Rampa 2 activa</div>'
                                    break;

                                    case 5:
                                    content += '<div class="col-span-3 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Lugar de CTRL remoto 1 activado</div>'
                                    break;

                                    case 6:
                                    content += '<div class="col-span-3 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Lugar de CTRL remoto 2 activado</div>'
                                    break;

                                    case 7:
                                    content += '<div class="col-span-3 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Control activo de bus de campo</div>'
                                    break;

                                    case 8:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Control activo local</div>'
                                    break;

                                    case 9:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Control activo de PC</div>'
                                    break;

                                    case 10:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Frecuencias constantes activas</div>'
                                    break;

                                    default:
                                    // Código para el caso por defecto
                                    break;
                                }

                            })

                            content += '</div>';

                        }else */

                        if(index == 9) {

                            sensor = sensor.toString();

                            let decode_word = [];

                            for (let i = 0; i < sensor.length; i++) {
                                decode_word.push((sensor[i] == 1 || sensor[i] == '1') ? true : false)
                            }

                            content = '<div class="grid grid-cols-3 m-0 cursor-default w-full gap-2 2xl:text-xl text-lg mt-1 mb-3">';

                            decode_word.forEach( (bool, index) => {

                                switch (index) {
                                    case 0:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + 'DO1</div>'
                                    break;

                                    case 1:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + 'DO2</div>'
                                    break;

                                    case 2:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + 'DO3</div>'
                                    break;

                                    default:
                                        // Código para el caso por defecto

                                    break;
                                }

                            })

                            content += '</div>';

                        }else if(index == 10) {

                            sensor = sensor.toString();

                            let decode_word = [];

                            for (let i = 0; i < sensor.length; i++) {
                                decode_word.push((sensor[i] == 1 || sensor[i] == '1') ? true : false)
                            }

                            content = '<div class="grid grid-cols-3 m-0 cursor-default w-full gap-2 2xl:text-xl text-lg mt-1 mb-3">';

                            decode_word.forEach( (bool, index) => {

                                switch (index) {
                                    case 0:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + ((this.ini_digital_inputs != null) ? this.ini_digital_inputs[0] : 'DI1') + '</div>'
                                    break;

                                    case 1:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + ((this.ini_digital_inputs != null) ? this.ini_digital_inputs[1] : 'DI2') + '</div>'
                                    break;

                                    case 2:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + ((this.ini_digital_inputs != null) ? this.ini_digital_inputs[2] : 'DI3') + '</div>'
                                    break;

                                    default:
                                        // Código para el caso por defecto

                                    break;
                                }

                            })

                            content += '</div>';

                        }else if(index == 8) {

                            sensor = sensor.toString();

                            // B0 = Preparado; B1 = Marcha; B2 = Inverso; B3 = Fallo; B6 = Permiso de marcha; B7 = Alarma activa; B12 = Solicitud de marcha; B13 = Regulador del motor activado

                            let decode_word = [];

                            for (let i = sensor.toString().length - 1; i >= 0; i--) {
                                decode_word.push((sensor.toString()[i] == 1 || sensor.toString()[i] == '1') ? true : false)
                            }

                            while(decode_word.length <= 13){
                                decode_word.push(false)
                            }

                            content = '<div class="grid grid-cols-6 m-0 cursor-default w-full gap-2 pt-1 2xl:text-xl text-lg">';

                            decode_word.forEach( (bool, index) => {

                                switch (index) {
                                    case 0:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Ready") + '</div>'
                                    break;

                                    case 1:
                                    content += '<div class="col-span-3 row-start-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Run") + '</div>'
                                    break;

                                    /*case 2:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Reverse") + '</div>'
                                    break;*/

                                    case 3:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-fault text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Fault") + '</div>'
                                    break;

                                    /*case 6:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-alarm text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Run_request") + '</div>'
                                    break;*/

                                    case 7:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-regulator text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Alarm") + '</div>'
                                    break;

                                    case 12:
                                    content += '<div class="col-span-3 row-start-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Run_enable") + '</div>'
                                    break;

                                    /*case 13:
                                    content += '<div class="col-span-3 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Regulator") + '</div>'
                                    break;*/

                                    default:
                                    // Código para el caso por defecto
                                    break;
                                }

                            })

                            content += '</div>';

                        }

                        setTimeout(() => {
                            document.getElementById("id_label_" + index).innerHTML = content;
                        }, 0);

                    }

                });

            } else if(this.data.MODBUS_device_type == 7 && this.page_StateParameters && this.data.data){

                let sensor_num = Object.keys(this.data.data).length;
                let index_i;

                let units = new Array(sensor_num);
                let names = new Array(sensor_num);
                let data = new Array(sensor_num);
                let dates;

                for (let sensor in this.data.data) {

                    if(sensor == 22 || sensor == 36){ // GRAFICOS

                        switch(sensor){
                            case '36': index_i = 0; break;
                            case '22': index_i = 1; break;
                        }

                        dates = new Array(this.data.data[sensor].length);
                        data[index_i] = new Array(this.data.data[sensor].length);
                        names[index_i] = this.data.names[sensor];
                        units[index_i] = this.data.units[sensor];

                        this.data.data[sensor].forEach((value, index) => {

                            dates[index] = new Date(
                                (this.data.dates[index] + " GMT")
                            ).getTime();

                            data[index_i][index] = parseFloat((parseFloat(value) * this.options_transducer[this.vmodel_transducer.id].ratio).toFixed(2));
                        });

                    }else if(!(sensor == 21|| sensor == 10 || sensor == 11 || sensor == 9)){ // GAUGES && TEXTS

                        index_i = null;

                        switch(sensor){
                            case '14': index_i = 2; break;
                            case '15': index_i = 3; break;
                            case '17': index_i = 4; break;
                            case '1': index_i = 5; break;
                            case '6': index_i = 6; break;
                            case '3': index_i = 7; break;
                            case '8': index_i = 12; break;
                        }

                        if(index_i != null){

                            document.getElementById("id_title_" + index_i).innerHTML = this.data.names[sensor];

                            data[index_i] = this.data.data[sensor][0];
                            names[index_i] = this.data.names[sensor];
                            units[index_i] = this.data.units[sensor];

                        }

                    } else if(sensor == 21|| sensor == 10 || sensor == 11 || sensor == 9){ // WORDS

                        switch(sensor){
                            case '21': index_i = 8; break;
                            case '9': index_i = 9; break;
                            case '10': index_i = 10; break;
                            case '11': index_i = 11; break;
                        }

                        document.getElementById("id_title_" + index_i).innerHTML = this.data.names[sensor];

                        data[index_i] = this.data.data[sensor][0];
                        names[index_i] = this.data.names[sensor];
                        units[index_i] = this.data.units[sensor] == null ? '' : this.data.units[sensor];

                    }

                }

                data.forEach((sensor, index) => {

                    let Chart = this.Chart;

                    if(typeof sensor === 'object'){ // GRAFICO

                        let highcharts_data = new Array(sensor.length);

                        sensor.forEach((measure, index) => {
                            highcharts_data[index] = [dates[index], parseFloat(measure)];
                        });

                        Chart.tooltip.valueSuffix = units[index];

                        Chart.series = [
                        {
                            name: names[index],
                            type: "spline",
                            data: highcharts_data.reverse(),
                            color: "#05fff3",
                            lineWidth: 1.5,
                            zIndex: 1,
                            marker: {
                            enabled: false,
                            },
                            tooltip: {
                                valueSuffix: units[index],
                            },
                        },
                        ];

                        Highcharts.chart("id_chart_" + index, Chart);

                    }else if(index == 2 || index == 3 || index == 4 || index == 5 || index == 6 || index == 7){ // GAUGE

                        let max;

                        switch(index){
                            case 5: max = 60; break;
                            case 6: max = 600; break;
                            case 7: max = 25; break;
                            default:  max = 100; break;
                        }

                        let min;

                        switch(index){
                            default:  min = 0; break;
                        }

                        Chart = {
                            chart: {
                                type: 'gauge',
                                backgroundColor: "transparent",
                                plotBackgroundColor: null,
                                plotBackgroundImage: null,
                                plotBorderWidth: 0,
                                plotShadow: false,
                                spacing: [0, 0, 0, 0], // Ajusta los márgenes del gráfico según tus necesidades
                                height: 120,
                                marginTop: -5, // Elimina el margen superior del gráfico
                                marginBottom: -35,
                            },
                            title: null,
                            pane: {
                                startAngle: -120,
                                endAngle: 120,
                                background: {
                                backgroundColor: "transparent",
                                borderWidth: 0
                                }
                            },
                            tooltip: {
                                enabled: false
                            },
                            xAxis: {
                                title: {
                                text: "",
                                style: {
                                    color: "#FFFAFA",
                                    fontSize: "12px",
                                    fontWeight: "normal",
                                    fontStyle: "normal"
                                }
                                },
                                labels: {
                                    rotation: -45,
                                    style: {
                                        color: 'white',
                                        fontSize: '10px' // Ajusta el tamaño de la fuente de las etiquetas según tus necesidades
                                    }
                                }
                            },
                            yAxis: {
                                min: min,
                                max: max,
                                tickPosition: 'outside',
                                lineColor: '#05fff3',
                                lineWidth: 1, // Ajusta el ancho de la línea del eje según tus necesidades
                                minorTickPosition: 'outside',
                                tickColor: '#05fff3',
                                minorTickColor: '#05fff3',
                                tickLength: 4, // Ajusta la longitud de las marcas del eje según tus necesidades
                                minorTickWidth: 1,
                                tickWidth: 1,
                                minorTickLength: 3, // Ajusta la longitud de las marcas menores del eje según tus necesidades
                                labels: {
                                distance: 6, // Ajusta la distancia de las etiquetas al eje según tus necesidades
                                rotation: 'auto',
                                style: {
                                    color: '#05fff3',
                                    fontSize: '10px' // Ajusta el tamaño de la fuente de las etiquetas según tus necesidades
                                }
                                },
                                tickPositions:
                                [
                                    min,
                                    min + (max-min)/4,
                                    min + (max-min)/2,
                                    min + 3*(max-min)/4,
                                    max
                                ],
                                offset: -10,
                                endOnTick: false
                            },
                            plotOptions: {
                                gauge: {
                                    borderWidth: 0,
                                    borderColor: "#05fff3", // Cambia el color del borde de la serie a #05fff3
                                    dataLabels: {
                                        enabled: false, // Desactiva las etiquetas con el dato y su unidad
                                    },
                                    pivot: {
                                        radius: "4%",
                                        backgroundColor: "#fff", // Cambia el color del pivote a blanco
                                    },
                                    dial: {
                                        backgroundColor: "#fff", // Cambia el color de la flecha a blanco
                                        radius: "70%", // Ajusta el tamaño de la flecha según tus necesidades
                                        baseWidth: 3, // Ajusta el ancho de la base de la flecha según tus necesidades
                                        topWidth: 1, // Ajusta el ancho de la punta de la flecha según tus necesidades
                                        baseLength: "10%", // Ajusta la longitud de la base de la flecha según tus necesidades
                                        rearLength: "-20%", // Ajusta la longitud de la punta de la flecha según tus necesidades
                                    }
                                },
                            },
                            credits: {
                                enabled: false
                            },
                            exporting: {
                                enabled: false,
                            },
                            series: [{
                                name: '',
                                data: [{
                                y:  parseFloat(sensor),
                                }],
                                tooltip: {
                                valueSuffix: ''
                                }
                            }]
                        };

                        Highcharts.chart("id_chart_" + index, Chart);

                        var content =
                        '<div class="content-between m-0 cursor-default text-base w-full pb-2">' +
                            '<div class="text-center flex justify-center items-center w-full whitespace-nowrap gap-2 pl-4">' +
                                '<p class="text-3xl font-sevensegment text-white-snow">' + sensor + '</p>' +
                                '<p class="text-white-snow pb-0.5 self-end text-left">' + units[index] + '</p>' +
                            '</div>' +
                        '</div>'

                        document.getElementById("id_label_" + index).innerHTML = content;

                    }else if(index == 12){ // TEXTS

                        var content = '';
                        var icon_class =
                            (index === 12) ? 'DK-temperatura' :
                            'hidden';

                        switch(index){
                            case 12:
                                content +=
                                '<div class="content-between m-0 cursor-default text-base w-full">' +
                                    '<div class="bg-cyan-opa px-2 mb-3 py-2 mt-1 text-center rounded-lg flex justify-center items-center w-full whitespace-nowrap gap-4">' +
                                        '<div class="h-6 w-6 rounded-full bg-transparent border border-white grid place-items-center justify-self-start">' +
                                            '<i class="' + icon_class + '" style="font-size:0.9rem; color:#FFFAFA;"></i>' +
                                        '</div>' +
                                        '<p class="text-3xl font-sevensegment text-white-snow">' + sensor + '</p>' +
                                        '<p class="text-white-snow self-end w-4 text-left pb-0.5">' + units[index] + '</p>' +
                                    '</div>' +
                                '</div>'
                                break;
                        }

                        document.getElementById("id_label_" + index).innerHTML = content;

                    } else { // WORDS

                        /*if( index == 11 ){

                            //B3 = Rampa 2 activa; B5 = Lugar de CTRL remoto 1 activado; B6 = Lugar de CTRL remoto 2 activado; B7 = Control activo de bus de campo; B8 = Control activo local; B9 = Control activo de PC; B10 = Frecuencias constantes activas

                            let decode_word = [];

                            for (let i = sensor.toString().length - 1; i >= 0; i--) {
                                decode_word.push((sensor.toString()[i] == 1 || sensor.toString()[i] == '1') ? true : false)
                            }

                            while(decode_word.length <= 10){
                                decode_word.push(false)
                            }

                            content = '<div class="grid grid-cols-6 m-0 cursor-default w-full gap-2 pt-1 2xl:text-xl text-lg">';

                            decode_word.forEach( (bool, index) => {

                                switch (index) {
                                    case 3:
                                    content += '<div class="col-span-3 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Rampa 2 activa</div>'
                                    break;

                                    case 5:
                                    content += '<div class="col-span-3 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Lugar de CTRL remoto 1 activado</div>'
                                    break;

                                    case 6:
                                    content += '<div class="col-span-3 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Lugar de CTRL remoto 2 activado</div>'
                                    break;

                                    case 7:
                                    content += '<div class="col-span-3 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Control activo de bus de campo</div>'
                                    break;

                                    case 8:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Control activo local</div>'
                                    break;

                                    case 9:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Control activo de PC</div>'
                                    break;

                                    case 10:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">Frecuencias constantes activas</div>'
                                    break;

                                    default:
                                    // Código para el caso por defecto
                                    break;
                                }

                            })

                            content += '</div>';

                        }else */

                        if(index == 11) {

                            sensor = sensor.toString();

                            let decode_word = [];

                            for (let i = 0; i < sensor.length; i++) {
                                decode_word.push((sensor[i] == 1 || sensor[i] == '1') ? true : false)
                            }

                            while(decode_word.length <= 3){
                                decode_word.push(false)
                            }

                            content = '<div class="grid grid-cols-3 m-0 cursor-default w-full gap-2 2xl:text-xl text-lg mt-1 mb-3">';

                            decode_word.forEach( (bool, index) => {

                                switch (index) {
                                    case 0:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + 'DO1</div>'
                                    break;

                                    case 1:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + 'DO2</div>'
                                    break;

                                    case 2:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + 'DO3</div>'
                                    break;

                                    default:
                                        // Código para el caso por defecto

                                    break;
                                }

                            })

                            content += '</div>';

                        }else if(index == 9) {

                            sensor = sensor.toString();

                            let decode_word = [];

                            for (let i = 0; i < 3; i++) {
                                decode_word.push((sensor[i] == 1 || sensor[i] == '1') ? true : false)
                            }

                            content = '<div class="grid grid-cols-3 m-0 cursor-default w-full gap-2 2xl:text-xl text-lg mt-1 mb-3">';

                            decode_word.forEach( (bool, index) => {

                                switch (index) {
                                    case 0:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + ((this.ini_digital_inputs != null) ? this.ini_digital_inputs[0] : 'DI1') + '</div>'
                                    break;

                                    case 1:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + ((this.ini_digital_inputs != null) ? this.ini_digital_inputs[1] : 'DI2') + '</div>'
                                    break;

                                    case 2:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + ((this.ini_digital_inputs != null) ? this.ini_digital_inputs[2] : 'DI3') + '</div>'
                                    break;

                                    default:
                                        // Código para el caso por defecto

                                    break;
                                }

                            })

                            content += '</div>';

                        }else if(index == 10) {

                            sensor = sensor.toString();

                            let decode_word = [];

                            for (let i = 0; i < 3; i++) {
                                decode_word.push((sensor[i] == 1 || sensor[i] == '1') ? true : false)
                            }

                            content = '<div class="grid grid-cols-3 m-0 cursor-default w-full gap-2 2xl:text-xl text-lg mt-1 mb-3">';

                            decode_word.forEach( (bool, index) => {

                                switch (index) {
                                    case 0:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + ((this.ini_digital_inputs != null) ? this.ini_digital_inputs[3] : 'DI4') + '</div>'
                                    break;

                                    case 1:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + ((this.ini_digital_inputs != null) ? this.ini_digital_inputs[4] : 'DI5') + '</div>'
                                    break;

                                    case 2:
                                    content += '<div class="w-full text-center rounded-md border border-gray-semimedium py-[11px] ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + ((this.ini_digital_inputs != null) ? this.ini_digital_inputs[5] : 'DI6') + '</div>'
                                    break;

                                    default:
                                        // Código para el caso por defecto

                                    break;
                                }

                            })

                            content += '</div>';

                        }else if(index == 8) {

                            sensor = sensor.toString();

                            // B1 = Preparado; B2 = En marcha; B3 = Fallo; B6 = PermisoMarcha; B7 = AlarmaActiva; B10 = Intensidad de CC al paro; B11 = Freno CC activo; B12 = PeticiónMarcha; B13 = ReguladorMotorActivo; B15 = Chopper de frenado activo

                            let decode_word = [];

                            for (let i = sensor.toString().length - 1; i >= 0; i--) {
                                decode_word.push((sensor.toString()[i] == 1 || sensor.toString()[i] == '1') ? true : false)
                            }

                            while(decode_word.length <= 13){
                                decode_word.push(false)
                            }

                            content = '<div class="grid grid-cols-6 m-0 cursor-default w-full gap-2 pt-1 2xl:text-xl text-lg">';

                            decode_word.forEach( (bool, index) => {

                                switch (index) {
                                    case 1:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Ready") + '</div>'
                                    break;

                                    case 2:
                                    content += '<div class="col-span-3 row-start-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Run") + '</div>'
                                    break;

                                    /*case 2:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Reverse") + '</div>'
                                    break;*/

                                    case 3:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-fault text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Fault") + '</div>'
                                    break;

                                    /*case 6:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-alarm text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Run_request") + '</div>'
                                    break;*/

                                    case 7:
                                    content += '<div class="col-span-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-regulator text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Alarm") + '</div>'
                                    break;

                                    case 12:
                                    content += '<div class="col-span-3 row-start-2 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Run_enable") + '</div>'
                                    break;

                                    /*case 13:
                                    content += '<div class="col-span-3 w-full text-center rounded-md border border-gray-semimedium py-1.5 ' + (bool ? 'bg-cyan-opa-2 text-white-snow' : 'text-white-snow' ) + '">' + this.$t("general.Regulator") + '</div>'
                                    break;*/

                                    default:
                                    // Código para el caso por defecto
                                    break;
                                }

                            })

                            content += '</div>';

                        }

                        setTimeout(() => {
                            document.getElementById("id_label_" + index).innerHTML = content;
                        }, 0);

                    }

                });

            }

        },

        mqtt_connection(iddevice) {

            var mqtt_topic = "/PUSHER/@P@" + this.user.idplatform + "/G@" + this.user.idgroup_selected + "/@D@" + iddevice;

            const mqtt = require('paho-mqtt');

            const mqtt_host = 'mqtt.datakorum.app';
            const mqtt_port = 8000;
            const mqtt_path = '';

            var userName = this.user.credentials.username;
            var password = this.user.credentials.password;

            var clientId = "APPclientid_" + parseInt(Math.random() * 100, 10);

            const client = new mqtt.Client(mqtt_host, mqtt_port, mqtt_path, clientId);

            client.connect({

            useSSL: true,
            mqttVersion: 4,
            userName: userName,
            password: password,

            onSuccess: () => {
                // función de éxito de conexión

                client.subscribe(mqtt_topic, {

                onSuccess: () => {
                    console.log('éxito de suscripción ' + iddevice)
                    // función de éxito de suscripción
                },

                onFailure: () => {
                    // función de fallo de suscripción
                    console.error('fallo de suscripción ' + iddevice)
                }

                });
            },

            onFailure: () => {
                // función de fallo de conexión
                console.error('fallo de conexión ' + iddevice)
            }

            });

            client.onConnectionLost = () => {
            // función que se ejecuta cuando perdemos la conexión
                console.error('perdida de conexión ' + iddevice)

                setTimeout(() => {
                    this.mqtt_connection(iddevice)
                }, 5000);

            };

            client.onMessageArrived = (message) => {
                // función que se ejecuta cuando llega un mensaje al topic suscrito

                var data = JSON.parse(JSON.parse(message.payloadString).frame_data);
                var when = this.formatDate(JSON.parse(message.payloadString).when * 1000);

                if(this.data.MODBUS_device_type == 6){

                    this.data.dates.unshift(when);

                    for (let sensor in this.data.data) {

                        //tener en cuenta la fecha para mañana cambiarlo

                        if(sensor != '10' && sensor != '11' && sensor != '12' && sensor != '13' ){
                            data[sensor] = parseFloat(data[sensor]);
                        }

                        if(sensor == '9' || sensor == '15'){
                            this.data.data[sensor].unshift(data[sensor]);
                        }else{
                            this.data.data[sensor][0] = data[sensor];
                        }
                    }

                } else if(this.data.MODBUS_device_type == 7){

                    this.data.dates.unshift(when);

                    for (let sensor in this.data.data) {

                        //tener en cuenta la fecha para mañana cambiarlo
                        if(sensor != '21'){
                            data[sensor] = parseFloat(data[sensor]);
                        }

                        if(sensor == '22' || sensor == '36'){
                            this.data.data[sensor].unshift(data[sensor]);
                        }else{
                            this.data.data[sensor][0] = data[sensor];
                        }
                    }
                }

                this.rechargePage();

            };
        },

        changePage(bool){
            this.page_StateParameters = bool;
            setTimeout(() => {
                this.rechargePage();
            }, 0);
        },

        Command(idcommand){

            if(this.timeout_command == undefined){

                this.SetTimerCommand();

                let command, data;

                switch(idcommand){
                    case 0:
                        command = 'OUTPUT-STATUS';
                        data = {
                            idoutput: "",
                            output_number: "1",
                            delay: "0",
                            timer: "0",
                            power: "100",
                            read_delay: this.data.read_delay,
                            send_delay: this.data.send_delay,
                            idstatus: (this.vmodel_idstatus.id).toString(),
                        };
                        break;

                    case 1:
                        command = 'registersVacon20';
                        data = {
                            corr_nom: (document.getElementById('id_rated_motor').value * 100).toString(),
                            arranque: (this.vmodel_startfunction.id).toString(),
                            parada: (this.vmodel_stopfunction.id).toString(),
                            frec_min: (document.getElementById('id_min_f').value * 100).toString(),
                            consigna: (document.getElementById('id_set_point').value * 10).toString(),
                            ganancia_p: (document.getElementById('id_prop_gain').value * 10).toString(),
                            tiempo_i: (document.getElementById('id_integration_time').value * 100).toString(),
                            tiempo_d: (document.getElementById('id_derivation_time').value * 100).toString(),
                            frec_min_dormir: (document.getElementById('id_min_sleep_f').value * 100).toString(),
                            retardo_dormir: (document.getElementById('id_sleep_delay').value).toString(),
                            error_despertar: (document.getElementById('id_wake_up_error').value * 10).toString(),
                            ocult_param: (this.vmodel_parameterhiding.id).toString(),
                            read_delay: this.data.read_delay,
                            send_delay: this.data.send_delay,
                        };
                        break;

                    case 2:
                        command = 'registersVacon100';
                        data = {
                            //rearme: (this.vmodel_rearme.id).toString(),
                            //consigna: (document.getElementById('id_consigna').value).toString(),
                            int_nom: (document.getElementById('id_int_nom').value).toString(),
                            frec_min: (document.getElementById('id_frec_min').value).toString(),
                            ganancia_pid: (document.getElementById('id_ganancia_pid').value).toString(),
                            tiempo_int_pid: (document.getElementById('id_tiempo_int_pid').value).toString(),
                            lim_frec_dormir_1: (document.getElementById('id_lim_frec_dormir_1').value).toString(),
                            retraso_dormir_sp1: (document.getElementById('id_retraso_dormir_sp1').value).toString(),
                            modo_despertar_ref_1_pid: (this.vmodel_modo_despertar_ref_1_pid.id).toString(),
                            nivel_despertar_1: (document.getElementById('id_nivel_despertar_1').value).toString(),
                            hora: (document.getElementById('id_hora').value).toString(),
                            fecha: (document.getElementById('id_fecha').value).toString(),
                            anyo: (document.getElementById('id_anyo').value).toString(),
                            read_delay: this.data.read_delay,
                            send_delay: this.data.send_delay,
                        };
                        break;

                    /*
                    case 3:
                        break;

                    // ...*/
                    default:
                        break;
                }


                window.emitter.emit('changeLoaderStatus', true, 'orbit')

                axios({
                    method: 'post',
                    url: window.location.origin + '/api/command/' + command + '/' + this.user.idplatform + '/' + this.user.idgroup_selected + '/' + this.data.id + '/' + this.user.id,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                    data: data
                })
                .then((response) => {
                    if(response.data[0]){

                        switch(idcommand){
                            case 0:
                                this.ini_idstatus = this.vmodel_idstatus.id;
                                break;

                            case 1:
                                this.ini_rated_motor = document.getElementById('id_rated_motor').value;
                                this.ini_min_f = document.getElementById('id_min_f').value;
                                this.ini_set_point = document.getElementById('id_set_point').value;
                                this.ini_prop_gain = document.getElementById('id_prop_gain').value;
                                this.ini_integration_time = document.getElementById('id_integration_time').value;
                                this.ini_derivation_time = document.getElementById('id_derivation_time').value;
                                this.ini_min_sleep_f = document.getElementById('id_min_sleep_f').value;
                                this.ini_sleep_delay = document.getElementById('id_sleep_delay').value;
                                this.ini_wake_up_error = document.getElementById('id_wake_up_error').value;
                                this.ini_startfunction = this.vmodel_startfunction.id;
                                this.ini_stopfunction = this.vmodel_stopfunction.id;
                                this.ini_parameterhiding = this.vmodel_parameterhiding.id;

                                break;

                            case 2:
                                this.ini_rearme = this.vmodel_rearme.id;
                                this.ini_consigna = document.getElementById('id_consigna').value;
                                this.ini_int_nom = document.getElementById('id_int_nom').value;
                                this.ini_frec_min = document.getElementById('id_frec_min').value;
                                this.ini_ganancia_pid = document.getElementById('id_ganancia_pid').value;
                                this.ini_tiempo_int_pid = document.getElementById('id_tiempo_int_pid').value;
                                this.ini_lim_frec_dormir_1 = document.getElementById('id_lim_frec_dormir_1').value;
                                this.ini_retraso_dormir_sp1 = document.getElementById('id_retraso_dormir_sp1').value;
                                this.ini_modo_despertar_ref_1_pid = this.vmodel_modo_despertar_ref_1_pid.id;
                                this.ini_nivel_despertar_1 = document.getElementById('id_nivel_despertar_1').value;
                                this.ini_hora = document.getElementById('id_hora').value;
                                this.ini_fecha = document.getElementById('id_fecha').value;
                                this.ini_anyo = document.getElementById('id_anyo').value;
                                break;

                            /*case 3:
                                break;

                            // ...*/
                            default:
                                break;
                        }

                    }else if(!response.data[0]){
                        console.error(response.data[1])
                    }

                    window.emitter.emit('changeLoaderStatus', false, 'orbit')

                })
                .catch((error) => {
                    window.emitter.emit('changeLoaderStatus', false, 'orbit')

                    if(error.response && error.response.status && error.response.status == 429){
                    window.alert( this.$t('text.Api attempts'));
                    }else{
                    return "Failed!", error;
                    }

                });
            }
        },

        CancelCommand(idcommand){

            switch(idcommand){
                case 0:
                    this.vmodel_idstatus = this.options_idstatus[this.ini_idstatus];
                    break;

                case 1:
                    document.getElementById('id_rated_motor').value = this.ini_rated_motor * 100;
                    document.getElementById('id_min_f').value = this.ini_min_f * 100;
                    document.getElementById('id_set_point').value = this.ini_set_point * 10;
                    document.getElementById('id_prop_gain').value = this.ini_prop_gain * 10;
                    document.getElementById('id_integration_time').value = this.ini_integration_time;
                    document.getElementById('id_derivation_time').value = this.ini_derivation_time;
                    document.getElementById('id_min_sleep_f').value = this.ini_min_sleep_f * 100;
                    document.getElementById('id_sleep_delay').value = this.ini_sleep_delay;
                    document.getElementById('id_wake_up_error').value = this.ini_wake_up_error * 10;
                    this.vmodel_startfunction = this.options_startfunction[this.ini_startfunction];
                    this.vmodel_stopfunction = this.options_stopfunction[this.ini_stopfunction];
                    this.vmodel_parameterhiding = this.options_parameterhiding[this.ini_parameterhiding];

                    break;

                case 2:
                    document.getElementById('id_consigna').value = this.ini_consigna;
                    document.getElementById('id_int_nom').value = this.ini_int_nom;
                    document.getElementById('id_frec_min').value = this.ini_frec_min;
                    document.getElementById('id_ganancia_pid').value = this.ini_ganancia_pid;
                    document.getElementById('id_tiempo_int_pid').value = this.ini_tiempo_int_pid;
                    document.getElementById('id_lim_frec_dormir_1').value = this.ini_lim_frec_dormir_1;
                    document.getElementById('id_retraso_dormir_sp1').value = this.ini_retraso_dormir_sp1;
                    document.getElementById('id_nivel_despertar_1').value = this.ini_nivel_despertar_1;
                    document.getElementById('id_hora').value = this.ini_hora;
                    document.getElementById('id_fecha').value = this.ini_fecha;
                    document.getElementById('id_anyo').value = this.ini_anyo;
                    this.vmodel_rearme = this.options_rearme[this.ini_rearme];
                    this.vmodel_modo_despertar_ref_1_pid = this.options_modo_despertar_ref_1_pid[this.ini_modo_despertar_ref_1_pid];

                    break;

                /*case 3:
                    break;

                // ...*/
                default:
                    break;
            }
        },

        SetTimerCommand(){
            const sendDelay = this.data.send_delay;
            this.timeout_command = 1;

                document.getElementById('id_update_button1').innerHTML = sendDelay - this.timeout_command;
                document.getElementById('id_update_button2').innerHTML = sendDelay - this.timeout_command;

            const intervalId = setInterval(() => {
                if (this.timeout_command < sendDelay) {
                    this.timeout_command++;

                        document.getElementById('id_update_button1').innerHTML = sendDelay - this.timeout_command;
                        document.getElementById('id_update_button2').innerHTML = sendDelay - this.timeout_command;

                } else {
                    clearInterval(intervalId);

                        document.getElementById('id_update_button1').innerHTML = this.$t('general.Update');
                        document.getElementById('id_update_button2').innerHTML = this.$t('general.Update');

                    this.timeout_command = undefined;
                }
            }, 1000);
        },

        set_options_transducer: function (item){

            this.vmodel_transducer = item

            let data = {transducer: item.id};

            axiosApiCalls.methodPut('/gateway/edit_descriptors/'+this.user.id+'/'+this.data.id, this.user.token, data)
            .then((response) => {
                return response;
            })

            setTimeout(() => {
                this.rechargePage();
            }, 0);
        },

        set_options_transducerAI1: function (item){

            this.vmodel_transducer = item

            let data = {transducerAI1: item.id};

            axiosApiCalls.methodPut('/gateway/edit_descriptors/'+this.user.id+'/'+this.data.id, this.user.token, data)
            .then((response) => {
                return response;
            })

            setTimeout(() => {
                this.rechargePage();
            }, 0);
        },

        set_options_transducerAI2: function (item){

            this.vmodel_transducer = item

            let data = {transducerAI2: item.id};

            axiosApiCalls.methodPut('/gateway/edit_descriptors/'+this.user.id+'/'+this.data.id, this.user.token, data)
            .then((response) => {
                return response;
            })

            setTimeout(() => {
                this.rechargePage();
            }, 0);
        },
    },
}
</script>
